@@ -30,7 +30,6 @@ use Error;
 use InvalidArgumentException;
 use LogicException;
 use MWDebug;
-use MWException;
 use UnexpectedValueException;
 use Wikimedia\Assert\Assert;
 use Wikimedia\NonSerializable\NonSerializableTrait;
@@ -107,12 +106,11 @@ class HookContainer implements SalvageableService {
 	 *
 	 * @param HookContainer|SalvageableService $other The object to salvage state from. $other be
 	 * of type HookContainer
-	 * @throws MWException
 	 */
 	public function salvage( SalvageableService $other ) {
 		Assert::parameterType( self::class, $other, '$other' );
 		if ( $this->handlers || $this->handlerObjects || $this->extraHandlers ) {
-			throw new MWException( 'salvage() must be called immediately after construction' );
+			throw new LogicException( 'salvage() must be called immediately after construction' );
 		}
 		$this->handlerObjects = $other->handlerObjects;
 		$this->handlers = $other->handlers;
@@ -185,7 +183,7 @@ class HookContainer implements SalvageableService {
 	 *
 	 * @param string $hook Name of hook to clear
 	 *
-	 * @internal For use by Hooks.php
+	 * @internal For testing only
 	 * @codeCoverageIgnore
 	 */
 	public function clear( string $hook ): void {
@@ -405,7 +403,7 @@ class HookContainer implements SalvageableService {
 	 * @return bool Whether the hook has a handler registered to it
 	 */
 	public function isRegistered( string $hook ): bool {
-		return !empty( $this->getHandlers( $hook ) );
+		return (bool)$this->getHandlers( $hook );
 	}
 
 	/**
@@ -686,7 +684,7 @@ class HookContainer implements SalvageableService {
 			return "$on::$func";
 		}
 
-		throw new LogicException( 'Unexpected kind of callable' );
+		throw new InvalidArgumentException( 'Unexpected kind of callable' );
 	}
 
 	/**
